==> kiten-17.08.3.tar.xz: kiten-17.08.3/radselect/kanji.h <==
/*****************************************************************************
 * This file is part of Kiten, a KDE Japanese Reference Tool                 *
 * Copyright (C) 2006 Joseph Kerian <jkerian@gmail.com>                      *
 *                                                                           *
 * This library is free software; you can redistribute it and/or             *
 * modify it under the terms of the GNU Library General Public               *
 * License as published by the Free Software Foundation; either              *
 * version 2 of the License, or (at your option) any later version.          *
 *                                                                           *
 * This library is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 * Library General Public License for more details.                          *
 *                                                                           *
 * You should have received a copy of the GNU Library General Public License *
 * along with this library; see the file COPYING.LIB.  If not, write to      *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 * Boston, MA 02110-1301, USA.                                               *
 *****************************************************************************/

#ifndef KANJI_H
#define KANJI_H

#include <QList>
#include <QSet>
#include <QString>

#include "radical.h"

class Kanji : public QString
{
  public:
                         Kanji();
                         Kanji(  const QString &kanji
                               , const QSet<QString> &radicals );

    void                 addRadical( const QString &it );
    void                 calculateStrokes( const QList<Radical> &lookup );
    const QSet<QString>& getRadicals() const;
    unsigned int         strokes() const;

    bool operator<( const Kanji &other ) const;

  protected:
    unsigned int  strokeCount;
    QSet<QString> components;
};

#endif

==> kiten_19.12.3.orig.tar.xz: kiten-19.12.3/radselect/kanji.h <==
/*****************************************************************************
 * This file is part of Kiten, a KDE Japanese Reference Tool                 *
 * Copyright (C) 2006 Joseph Kerian <jkerian@gmail.com>                      *
 *                                                                           *
 * This library is free software; you can redistribute it and/or             *
 * modify it under the terms of the GNU Library General Public               *
 * License as published by the Free Software Foundation; either              *
 * version 2 of the License, or (at your option) any later version.          *
 *                                                                           *
 * This library is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
 * Library General Public License for more details.                          *
 *                                                                           *
 * You should have received a copy of the GNU Library General Public License *
 * along with this library; see the file COPYING.LIB.  If not, write to      *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
 * Boston, MA 02110-1301, USA.                                               *
 *****************************************************************************/

#ifndef KANJI_H
#define KANJI_H

#include <QList>
#include <QSet>
#include <QString>

#include "radical.h"

class Kanji : public QString
{
  public:
                         Kanji();
    explicit             Kanji(  const QString &kanji
                               , const QSet<QString> &radicals );

    void                 addRadical( const QString &it );
    void                 calculateStrokes( const QList<Radical> &lookup );
    const QSet<QString>& getRadicals() const;
    unsigned int         strokes() const;

    bool operator<( const Kanji &other ) const;

  protected:
    unsigned int  strokeCount;
    QSet<QString> components;
};

#endif
